_`umbra.components.factory.scriptEditor.editorStatus`
=====================================================

.. automodule:: umbra.components.factory.scriptEditor.editorStatus

Module Attributes
-----------------

.. attribute:: umbra.components.factory.scriptEditor.editorStatus.LOGGER

.. attribute:: umbra.components.factory.scriptEditor.editorStatus.UI_FILE

Classes
-------

.. autoclass:: EditorStatus
	:show-inheritance:
	:members:

